@@ -1,7 +1,7 @@
 import logging
 import yaml
 import os
-from marshmallow import Schema, fields, pprint, post_load
+from marshmallow import Schema, fields, pprint, post_load, ValidationError
 
 logger = logging.getLogger(__name__)
 
@@ -15,18 +15,18 @@ class OntologyConfigSchema(Schema):
     pre_load = fields.Bool(description="if true, load this ontology at startup")
 
     @post_load
-    def make_object(self, data):
+    def make_object(self, data, **kwargs):
         return OntologyConfig(**data)
 
 class EndpointSchema(Schema):
     """
     Configuration for a REST or RESTish endpoint
     """
-    url = fields.Url()
+    url = fields.Url(require_tld=False)
     timeout = fields.Int()
 
     @post_load
-    def make_object(self, data):
+    def make_object(self, data, **kwargs):
         return Endpoint(**data)
 
 class CategorySchema(Schema):
@@ -37,7 +37,7 @@ class CategorySchema(Schema):
     superclass = fields.Str()
 
     @post_load
-    def make_object(self, data):
+    def make_object(self, data, **kwargs):
         return Category(**data)
 
 class ConfigSchema(Schema):
@@ -61,7 +61,7 @@ class ConfigSchema(Schema):
     use_amigo_for = fields.List(fields.Str(description="category to use amigo for"))
 
     @post_load
-    def make_object(self, data):
+    def make_object(self, data, **kwargs):
         return Config(**data)
 
 class Endpoint():
@@ -232,10 +232,11 @@ def load_config(path):
     f = open(path,'r')
     obj = yaml.load(f, Loader=yaml.FullLoader)
     schema = ConfigSchema()
-    config = schema.load(obj).data
-    errs = schema.validate(obj)
-    if len(errs) > 0:
-        logger.error("CONFIG ERRS: {}".format(errs))
-        raise ValueError('Error loading '+path)
-    #config = Config()
+    try:
+        config = schema.load(obj)
+    except ValidationError as err:
+        errors = err.messages
+        logger.error("CONFIG ERRS: {}".format(errors))
+        raise ValueError('Error loading ' + path)
+        
     return config
