@@ -40,6 +40,7 @@ import json
 import logging
 import pysolr
 import re
+from dataclasses import asdict
 from typing import Dict, List
 import xml.etree.ElementTree as ET
 from collections import OrderedDict
@@ -47,7 +48,8 @@ from ontobio.vocabulary.relations import HomologyTypes
 from ontobio.model.GolrResults import SearchResults, AutocompleteResult, Highlight
 from ontobio.util.user_agent import get_user_agent
 from prefixcommons.curie_util import expand_uri
-from ontobio.util.scigraph_util import get_curie_map
+from ontobio.util.curie_map import get_curie_map
+from ontobio import ecomap
 
 INVOLVED_IN="involved_in"
 ACTS_UPSTREAM_OF_OR_WITHIN="acts_upstream_of_or_within"
@@ -55,6 +57,9 @@ ACTS_UPSTREAM_OF_OR_WITHIN="acts_upstream_of_or_within"
 ISA_PARTOF_CLOSURE="isa_partof_closure"
 REGULATES_CLOSURE="regulates_closure"
 
+ecomapping = ecomap.EcoMap()
+iea_eco = ecomapping.coderef_to_ecoclass("IEA")
+
 logger = logging.getLogger(__name__)
 
 
@@ -338,6 +343,7 @@ class GolrSearchQuery(GolrAbstractQuery):
                  facet_fields=None,
                  facet=True,
                  search_fields=None,
+                 taxon_map=True,
                  rows=100,
                  start=None,
                  prefix=None,
@@ -360,6 +366,7 @@ class GolrSearchQuery(GolrAbstractQuery):
         self.facet = facet
         self.facet_fields = facet_fields
         self.search_fields = search_fields
+        self.taxon_map = taxon_map
         self.rows = rows
         self.start = start
         # test if client explicitly passes a URL; do not override
@@ -418,7 +425,7 @@ class GolrSearchQuery(GolrAbstractQuery):
     def solr_params(self, mode=None):
 
         if self.facet_fields is None and self.facet:
-            self.facet_fields = ['category', 'taxon_label']
+            self.facet_fields = ['category', 'taxon', 'taxon_label']
 
         if self.category is not None:
             self.fq['category'] = self.category
@@ -475,6 +482,10 @@ class GolrSearchQuery(GolrAbstractQuery):
             params['facet.limit'] = 25
             params['facet.mincount'] = 1
 
+        if self.taxon_map:
+            params["facet.pivot.mincount"] =1
+            params["facet.pivot"] = "taxon,taxon_label"
+
         if self.start is not None:
             params['start'] = self.start
 
@@ -586,12 +597,25 @@ class GolrSearchQuery(GolrAbstractQuery):
                 doc['id'] = doc['entity']
                 doc['label'] = doc['entity_label']
 
+        translated_facets = translate_facet_field(results.facets)
+
+        # inject the taxon map (aka a facet pivot) into the returned facets
+        if self.taxon_map:
+            translated_facets['_taxon_map'] = [
+                {
+                    'id': taxon['value'],
+                    'label': taxon['pivot'][0]['value'],
+                    'count': taxon['pivot'][0]['count']
+                }
+                for taxon in results.facets['facet_pivot']['taxon,taxon_label']
+            ]
+
         highlighting = {
-            doc['id']: self._process_highlight(results, doc)._asdict()
+            doc['id']: asdict(self._process_highlight(results, doc))
             for doc in results.docs if results.highlighting
         }
         payload = SearchResults(
-            facet_counts=translate_facet_field(results.facets),
+            facet_counts=translated_facets,
             highlighting=highlighting,
             docs=results.docs,
             numFound=results.hits
@@ -851,7 +875,7 @@ class GolrAssociationQuery(GolrAbstractQuery):
 
     exclude_automatic_assertions : bool
 
-        If true, then any annotations with evidence of ECO:0000501 (IEA) or
+        If true, then any annotations with ECO evidence code for IEA or
         subclasses will be excluded.
 
     use_compact_associations : bool
@@ -865,6 +889,8 @@ class GolrAssociationQuery(GolrAbstractQuery):
         See :ref:`Config` for details. The config object can be used
         to set values for the solr instance to be queried
 
+    TODO - Extract params into their own object
+
     """
     def __init__(self,
                  subject_category=None,
@@ -993,6 +1019,7 @@ class GolrAssociationQuery(GolrAbstractQuery):
         if self.facet_fields is None:
             if self.facet:
                 self.facet_fields = [
+                    M.SUBJECT_TAXON,
                     M.SUBJECT_TAXON_LABEL,
                     M.OBJECT_CLOSURE
                 ]
@@ -1206,7 +1233,7 @@ class GolrAssociationQuery(GolrAbstractQuery):
                 fq['evidence_object_closure'] = e
 
         if self.exclude_automatic_assertions:
-            fq['-evidence_object_closure'] = 'ECO:0000501'
+            fq['-evidence_object_closure'] = iea_eco
 
         # Homolog service params
         # TODO can we sync with argparse.choices?
