@@ -10,6 +10,7 @@ from prefixcommons import curie_util
 from ontobio.model import association
 from ontobio.rdfgen import relations
 
+import functools
 import logging
 import copy
 
@@ -84,6 +85,9 @@ def load_gaferencer_inferences_from_file(gaferencer_out) -> Dict[AnnotationKey,
 
     return build_annotation_inferences(gaferencer_out_dict)
 
+def load_gaferencer_inferences_from_files(gaferencer_out_list) -> Dict[AnnotationKey, InferenceValue]:
+    return functools.reduce(load_gaferencer_inferences_from_file, gaferencer_out_list, dict())
+
 
 def build_annotation_inferences(gaferencer_out: List[Dict]) -> Dict[AnnotationKey, InferenceValue]:
     inferences = dict()  # type Dict[AnnotationKey, InferenceValue]
@@ -133,9 +137,9 @@ def make_conjunctions(extension: List) -> association.ConjunctiveSet:
 relation_tuple = re.compile(r"(.+)\((.+)\)")
 def make_keys_from_gaf(gaf: association.GoAssociation) -> List[AnnotationKey]:
 
-    term = curie_util.expand_uri(gaf.object.id, cmaps=[prefix_context])
-    relation = curie_util.expand_uri(gaf.relation, cmaps=[prefix_context])
-    taxon = curie_util.expand_uri(gaf.object.taxon, cmaps=[prefix_context])
+    term = curie_util.expand_uri(str(gaf.object.id), cmaps=[prefix_context])
+    relation = curie_util.expand_uri(str(gaf.relation), cmaps=[prefix_context])
+    taxon = curie_util.expand_uri(str(gaf.object.taxon), cmaps=[prefix_context])
     extensions = gaf.object_extensions # type: List[association.ConjunctiveSet]
 
     annotation_keys = []  # type: List[AnnotationKey]
