@@ -56,6 +56,7 @@ class Ontology():
         self.graphdoc = graphdoc
 
         self.all_logical_definitions = []
+        self.all_property_chain_axioms = []
 
         # alternatively accept a payload object
         if payload is not None:
@@ -145,12 +146,18 @@ class Ontology():
             g = self.get_graph()
             srcg = ont.get_graph()
             for n in srcg.nodes():
-                g.add_node(n, **srcg.node[n])
+                g.add_node(n, **srcg.nodes[n])
             for (o,s,m) in srcg.edges(data=True):
                 g.add_edge(o,s,**m)
             if ont.xref_graph is not None:
                 for (o,s,m) in ont.xref_graph.edges(data=True):
                     self.xref_graph.add_edge(o,s,**m)
+            if ont.all_logical_definitions is not None:
+                for ld in ont.all_logical_definitions:
+                    self.add_logical_definition(ld)
+            if ont.all_property_chain_axioms is not None:
+                for pca in ont.all_property_chain_axioms:
+                    self.add_property_chain_axiom(pca)
 
     def subgraph(self, nodes=None):
         """
@@ -335,13 +342,13 @@ class Ontology():
 
         Wraps networkx by default
         """
-        return self.get_graph().node.get(id, None)
+        return self.get_graph().nodes.get(id, None)
 
     def has_node(self, id):
         """
         True if id identifies a node in the ontology graph
         """
-        return id in self.get_graph().node
+        return id in self.get_graph().nodes()
 
     def sorted_nodes(self):
         """
@@ -669,6 +676,11 @@ class Ontology():
         else:
             return []
 
+    def add_logical_definition(self, logical_def):
+        if self.all_logical_definitions is None:
+            self.all_logical_definitions = []
+        self.all_logical_definitions.append(logical_def)
+
     def get_property_chain_axioms(self, nid):
         """
         Retrieves property chain axioms for a class id
@@ -688,6 +700,11 @@ class Ontology():
         else:
             return []
 
+    def add_property_chain_axiom(self, pca):
+        if self.all_property_chain_axioms is None:
+            self.all_property_chain_axioms = []
+        self.all_property_chain_axioms.append(pca)
+
     def get_node_type(self, nid):
         n = self.node(nid)
         if 'type' in n:
@@ -784,6 +801,19 @@ class Ontology():
             syns.append(Synonym(nid, val=self.label(nid), pred='label'))
         return syns
 
+    def obo_namespace(self, nid):
+        go_namespace = [predval for predval in
+                        self.get_graph().nodes
+                            .get(nid, {})
+                            .get("meta", {})
+                            .get("basicPropertyValues", []) if predval["pred"] == "OIO:hasOBONamespace"]
+
+        if len(go_namespace) >= 1:
+            return go_namespace[0]["val"]
+        else:
+            return None
+
+
     def add_node(self, id, label=None, type='CLASS', meta=None):
         """
         Add a new node to the ontology
@@ -903,7 +933,7 @@ class Ontology():
         """
         g = self.get_graph()
         if nid in g:
-            n = g.node[nid]
+            n = g.nodes[nid]
             if 'label' in n:
                 return n['label']
             else:
@@ -1109,7 +1139,7 @@ class Synonym(AbstractPropertyValue):
         hasNarrowSynonym='narrow',
         hasRelatedSynonym='related')
 
-    def __init__(self, class_id, val=None, pred='hasRelatedSynonym', lextype=None, xrefs=None, ontology=None, confidence=1.0):
+    def __init__(self, class_id, val=None, pred='hasRelatedSynonym', lextype=None, xrefs=None, ontology=None, confidence=1.0, synonymType=None):
         """
         Arguments
         ---------
@@ -1125,7 +1155,7 @@ class Synonym(AbstractPropertyValue):
              Provenance or cross-references to same usage
 
         """
-        pred = pred.replace("http://www.geneontology.org/formats/oboInOwl#","")
+        pred = pred.replace("http://www.geneontology.org/formats/oboInOwl#", "")
         self.class_id = class_id
         self.val = val
         self.pred = pred
@@ -1133,9 +1163,11 @@ class Synonym(AbstractPropertyValue):
         self.xrefs = xrefs
         self.ontology = ontology
         self.confidence = confidence
+        self.synonymType = synonymType
 
     def __str__(self):
-        return '{} "{}" {} {} {} {}'.format(self.class_id, self.val, self.pred, self.lextype, self.xrefs, self.confidence)
+        return '{} "{}" {} {} {} {} {}'.format(self.class_id, self.val, self.pred, self.lextype, self.xrefs, self.confidence, self.synonymType)
+
     def __repr__(self):
         return self.__str__()
 
@@ -1168,7 +1200,7 @@ class Synonym(AbstractPropertyValue):
         }
 
     def __cmp__(self, other):
-        (x,y) = (str(self),str(other))
+        (x, y) = (str(self), str(other))
         if x > y:
             return 1
         if x < y:
