@@ -8,22 +8,26 @@ from ontobio.assoc_factory import AssociationSetFactory
 from ontobio.ontol_factory import OntologyFactory
 from ontobio.model import association
 from ontobio.rdfgen import relations
-
+from ontobio.model.association import ConjunctiveSet, ExtensionUnit, Curie
 from ontobio.ecomap import EcoMap
 
-ecomap = EcoMap()
-ecomap.mappings()
-
 import tempfile
 import logging
 import pytest
 import io
 import json
 
+ecomap = EcoMap()
+ecomap.mappings()
+
 POMBASE = "tests/resources/truncated-pombase.gaf"
 POMBASE_GPAD = "tests/resources/truncated-pombase.gpad"
 ONT = "tests/resources/go-truncated-pombase.json"
 QGAF = "tests/resources/test-qualifiers.gaf"
+ALT_ID_ONT = "tests/resources/obsolete.json"
+ZFIN_GAF = "tests/resources/zfin_test_gaf.gaf"
+OBSOLETE_ONT = "tests/resources/obsolete.json"
+
 
 def test_skim_gaf():
     p = GafParser()
@@ -36,6 +40,7 @@ def test_skim_gaf():
         assert o.startswith('GO:')
         assert s.startswith('PomBase:')
 
+
 def test_skim_gaf_qualifiers():
     p = GafParser()
     p.config.ecomap = EcoMap()
@@ -56,12 +61,14 @@ def test_skim_gaf_qualifiers():
         assert s.startswith('MGI:') or s.startswith('PomBase')
     assert len(results) == 3 # ensure NOTs and excludes relations skipped
 
+
 def test_one_line():
     p = GafParser(config=assocparser.AssocParserConfig(
         ontology=OntologyFactory().create("tests/resources/goslim_generic.json")))
 
     parsed = p.parse_line("PomBase	SPBC16D10.09	pcn1		GO:0009536	PMID:8663159	IDA		C	PCNA	pcn	protein	taxon:4896	20150326	PomBase")
 
+
 def test_skim_gpad():
     p = GpadParser()
     p.config.ecomap = EcoMap()
@@ -73,12 +80,15 @@ def test_skim_gpad():
         assert o.startswith('GO:')
         assert s.startswith('PomBase:') or s.startswith('PR:')
 
+
 def test_parse_gaf():
     parse_with(POMBASE, GafParser())
 
+
 def test_parse_gpad():
     parse_with(POMBASE_GPAD, GpadParser())
 
+
 def parse_with(f, p):
     p.config.ecomap = EcoMap()
     is_gaf = f == POMBASE
@@ -117,9 +127,10 @@ def parse_with(f, p):
     #     print("MESSAGE: {}".format(m))
     print("MESSAGES (sample): {}".format(p.report.messages[0:5]))
     # Messages that aren't about upgrading qualifiers in rule 59 should be 0
-    assert len([msg for msg in p.report.messages if msg["rule"] != 59]) == 0
+    assert len([msg for msg in p.report.messages if msg["rule"] != 59 and msg["rule"] != 27]) == 0
     # print(p.report.to_markdown())
 
+
 def test_flag_invalid_id():
     ont = OntologyFactory().create(ONT)
     p = GafParser()
@@ -127,6 +138,7 @@ def test_flag_invalid_id():
     p._validate_ontology_class_id("FAKE:1", assocparser.SplitLine("fake", [""]*17, taxon="foo"))
     assert len(p.report.messages) == 1
 
+
 def test_no_flag_valid_id():
     ont = OntologyFactory().create(ONT)
     p = GafParser()
@@ -134,6 +146,7 @@ def test_no_flag_valid_id():
     p._validate_ontology_class_id("GO:0000785", assocparser.SplitLine("fake", [""]*17, taxon="foo"))
     assert len(p.report.messages) == 0
 
+
 def test_convert_gaf_to_gpad():
     p = GafParser()
     p.config.ecomap = EcoMap()
@@ -141,6 +154,7 @@ def test_convert_gaf_to_gpad():
     p2 = GpadParser()
     convert(POMBASE, p, w, p2)
 
+
 def convert(file, p, w, p2):
     assocs = p.parse(file, skipheader=True)
     outfile = tempfile.NamedTemporaryFile(mode='w', delete=False)
@@ -166,6 +180,7 @@ def test_invalid_goid_in_gpad():
     assert len(p.report.messages) > 500
     print(p.report.to_markdown())
 
+
 def test_validate_go_idspaces():
     ont = OntologyFactory().create(ONT)
     p = GafParser()
@@ -182,15 +197,11 @@ def test_validate_go_idspaces():
 
     # ensure config is not preserved
     p = GafParser()
-    assert p.config.class_idspaces == None
+    assert p.config.class_idspaces is None
 
-#POMBASE_GPAD = "tests/resources/truncated-pombase.gpad"
 
 def test_qualifiers_gaf():
-    # ont = OntologyFactory().create(ONT)
-
     p = GafParser()
-    # p.config.ontology = ont
     assocs = p.parse(open(QGAF, "r"), skipheader=True)
     neg_assocs = [a for a in assocs if a.negated == True]
     assert len(neg_assocs) == 3
@@ -204,6 +215,14 @@ def test_qualifiers_gaf():
     assert len(list(filter(lambda e: e["obj"] == "involved_in", p.report.to_report_json()["messages"]["gorule-0000001"]))) == 1
 
 
+def test_gaf_2_1_unknown_qualifier():
+    line = ["UniProtKB", "P0AFI2", "parC", "Contributes_to", "GO:0003916", "PMID:1334483", "IDA", "", "F", "", "", "gene", "taxon:83333", "20081208", "EcoliWiki"]
+    parsed = gafparser.to_association(line)
+
+    assert parsed.skipped is True
+    assert parsed.report.to_report_json()["messages"]["gorule-0000001"][0]["type"] == parsed.report.INVALID_QUALIFIER
+
+
 def test_qualifiers_gaf_2_2():
 
     p = GafParser()
@@ -212,8 +231,6 @@ def test_qualifiers_gaf_2_2():
     # NOT by itself is not allowed
     assert len(list(filter(lambda e: e["obj"] == "NOT", p.report.to_report_json()["messages"]["gorule-0000001"]))) == 1
     assert len(list(filter(lambda e: e["obj"] == "contributes_to|enables", p.report.to_report_json()["messages"]["gorule-0000001"]))) == 1
-
-
     assert len([a for a in assocs if association.Curie.from_str("RO:0004035") in a.qualifiers]) == 1
 
 
@@ -230,6 +247,7 @@ def test_gaf_2_1_creates_cell_component_closure():
 
     assert "GO:0005840" in p.cell_component_descendants_closure
 
+
 def test_gaf_2_1_qualifiers_upconvert():
     line = ["SGD", "S000000819", "AFG3", "", "GO:0005840", "PMID:8681382|SGD_REF:S000055187", "IMP", "", "P", "Mitochondrial inner membrane m-AAA protease component", "YER017C|AAA family ATPase AFG3|YTA10", "gene", "taxon:559292", "20170428", "SGD"]
     parsed = gafparser.to_association(line)
@@ -242,6 +260,7 @@ def test_gaf_2_1_qualifiers_upconvert():
     assoc = p.upgrade_empty_qualifier(assoc)
     assert assoc.qualifiers[0] == association.Curie(namespace="BFO", identity="0000050")
 
+
 def test_gaf_2_1_upconvert_in_parse():
     gaf = io.StringIO("!gaf-version: 2.1\nSGD\tS000000819\tAFG3\t\tGO:0005840\tPMID:8681382|SGD_REF:S000055187\tIMP\t\tP\tMitochondrial inner membrane m-AAA protease component\tYER017C|AAA family ATPase AFG3|YTA10\tgene\ttaxon:559292\t20170428\tSGD")
     ontology = OntologyFactory().create("tests/resources/goslim_generic.json")
@@ -251,6 +270,7 @@ def test_gaf_2_1_upconvert_in_parse():
     assocs = p.parse(gaf, skipheader=True)
     assert assocs[0].relation == association.Curie(namespace="BFO", identity="0000050")
 
+
 def test_gaf_2_1_simple_terms():
     line = ["SGD", "S000000819", "AFG3", "", "GO:0006259", "PMID:8681382|SGD_REF:S000055187", "IMP", "", "P", "Mitochondrial inner membrane m-AAA protease component", "YER017C|AAA family ATPase AFG3|YTA10", "gene", "taxon:559292", "20170428", "SGD"]
     ontology = OntologyFactory().create("tests/resources/goslim_generic.json")
@@ -283,6 +303,7 @@ def test_gaf_2_1_simple_terms():
     assoc = p.upgrade_empty_qualifier(parsed.associations[0])
     assert assoc.qualifiers[0] == association.Curie(namespace="RO", identity="0001025")
 
+
 def test_upgrade_qualifiers_for_biological_process():
     line = ["SGD", "S000000819", "AFG3", "", "GO:0008150", "PMID:8681382|SGD_REF:S000055187", "IMP", "", "P",
             "Mitochondrial inner membrane m-AAA protease component", "YER017C|AAA family ATPase AFG3|YTA10", "gene",
@@ -295,6 +316,7 @@ def test_upgrade_qualifiers_for_biological_process():
     assoc = p.upgrade_empty_qualifier(parsed.associations[0])
     assert assoc.qualifiers[0] == association.Curie(namespace="RO", identity="0002331")
 
+
 def test_upgrade_qualifiers_for_cell_component():
     line = ["SGD", "S000000819", "AFG3", "", "GO:0008372", "PMID:8681382|SGD_REF:S000055187", "IMP", "", "P",
             "Mitochondrial inner membrane m-AAA protease component", "YER017C|AAA family ATPase AFG3|YTA10", "gene",
@@ -310,9 +332,7 @@ def test_upgrade_qualifiers_for_cell_component():
 
 def test_default_gaf_version():
     p = GafParser()
-
     assocs = p.parse(open("tests/resources/test-qualifiers-no-version.gaf"), skipheader=True)
-
     assert p.version == "2.1"
 
 
@@ -328,6 +348,7 @@ def parse_with2(f, p):
     assert len([a for a in assocs if str(a.relation) == relations.lookup_label('involved_in')]) == 1
     assert len([a for a in assocs if str(a.relation) == relations.lookup_label('contributes_to')]) == 1
 
+
 def test_errors_gaf():
     config = assocparser.AssocParserConfig(
         ecomap=EcoMap()
@@ -361,7 +382,6 @@ def test_errors_gaf():
                 assert x.term == association.Curie.from_str('X:1')
             assert len(xs) == 1
 
-ALT_ID_ONT = "tests/resources/obsolete.json"
 
 def test_alt_id_repair():
     p = GafParser()
@@ -379,6 +399,7 @@ def test_alt_id_repair():
     # GO:4 is obsolete due to it being merged into GO:3
     assert assocs[0].object.id == association.Curie.from_str("GO:3")
 
+
 def test_gorule_repair():
     config = assocparser.AssocParserConfig(
         ontology=OntologyFactory().create("tests/resources/goslim_generic.json"),
@@ -393,12 +414,14 @@ def test_gorule_repair():
     assert len(p.report.to_report_json()["messages"]["gorule-0000028"]) == 1
     assert p.report.to_report_json()["messages"]["gorule-0000028"][0]["type"] == assocparser.Report.VIOLATES_GO_RULE
 
+
 def test_bad_date():
     p = GafParser()
     assoc_result = p.parse_line("PomBase\tSPAC25B8.17\typf1\t\tGO:0000007\tGO_REF:0000024\tISO\tSGD:S000001583\tC\tintramembrane aspartyl protease of the perinuclear ER membrane Ypf1 (predicted)\tppp81\tprotein\ttaxon:4896\tTODAY\tPomBase\tfoo(X:1)")
     assert assoc_result.skipped == True
     assert assoc_result.associations == []
 
+
 def test_subject_extensions():
     p = GafParser()
     assoc_result = p.parse_line("PomBase\tSPAC25B8.17\typf1\t\tGO:0000007\tGO_REF:0000024\tISO\tSGD:S000001583\tC\tintramembrane aspartyl protease of the perinuclear ER membrane Ypf1 (predicted)\tppp81\tprotein\ttaxon:4896\t20181024\tPomBase\tpart_of(X:1)\tUniProtKB:P12345")
@@ -408,6 +431,7 @@ def test_subject_extensions():
     gene_product_form_id = subject_extensions[0].term
     assert gene_product_form_id == association.Curie.from_str("UniProtKB:P12345")
 
+
 def test_bad_withfrom():
     p = GafParser()
     # With/from has no identity portion after the namespace
@@ -415,6 +439,23 @@ def test_bad_withfrom():
     assert assoc_result.associations == []
     assert p.report.to_report_json()["messages"]["gorule-0000001"][0]["obj"] == "SGD:"
 
+
+def test_obsolete_replair_of_withfrom():
+    p = GafParser(config=assocparser.AssocParserConfig(
+        ontology=OntologyFactory().create(OBSOLETE_ONT)))
+    assocs = p.parse(open(ZFIN_GAF, "r"), skipheader=True)
+    assert assocs[0].evidence.with_support_from == [ConjunctiveSet(elements=[Curie(namespace='GO', identity='0005912')])]
+
+    # Reset parser report
+    p = GafParser(config=assocparser.AssocParserConfig(
+        ontology=OntologyFactory().create(OBSOLETE_ONT)))
+    p.version = "2.2"
+    obsolete_no_replacement_line = "FB\tFBgn0003334\tScm\tlocated_in\tGO:0005634\tFB:FBrf0179383|PMID:15280237\tIC\tGO:0016458\tC\tSex comb on midleg\tCG9495|SCM|Sex Comb on Midleg|Sex Comb on the Midleg|Sex combs on midleg|Sex combs on midlegs|Su(z)302|l(3)85Ef|scm|sex comb on midleg\tprotein\ttaxon:7227\t20050203\tUniProt\t\t"
+    assoc_result = p.parse_line(obsolete_no_replacement_line)
+    assert assoc_result.associations == []
+    assert p.report.to_report_json()["messages"]["gorule-0000020"][0]["obj"] == "GO:0016458"
+
+
 def test_subject_extensions_bad_curie():
     """
     Offending field is `GDP_bound`
@@ -441,11 +482,13 @@ def test_object_extensions():
     ]
     assert assoc_result.associations[0].object_extensions == object_extensions
 
+
 def test_object_extensions_error():
     p = GafParser()
     assoc_result = p.parse_line("PomBase\tSPAC25B8.17\typf1\t\tGO:0000007\tGO_REF:0000024\tISO\tSGD:S000001583\tC\tintramembrane aspartyl protease of the perinuclear ER membrane Ypf1 (predicted)\tppp81\tprotein\ttaxon:4896\t20181024\tPomBase\tpart_of(X)\tUniProtKB:P12345")
     assert len(p.report.to_report_json()["messages"]["gorule-0000001"]) == 1
 
+
 def test_factory():
     afa = AssociationSetFactory()
     ont = OntologyFactory().create(ONT)
@@ -472,6 +515,7 @@ def test_factory():
     assert len(aset.associations_by_subj) > 0
     assert found == 2
 
+
 def test_gaf_gpi_bridge():
     gaf = ["MGI", "MGI:1923503", "0610006L08Rik", "enables", "GO:0003674", "MGI:MGI:2156816|GO_REF:0000015", "ND", "",
            "F", "RIKEN cDNA 0610006L08 gene", "", "gene", "taxon:10090", "20120430", "MGI", "", ""]
